// ****************************************************************************
//  Project:        GUYMAGER
// ****************************************************************************
//  Programmer:     Guy Voncken
//                  Police Grand-Ducale
//                  Service de Police Judiciaire
//                  Section Nouvelles Technologies
// ****************************************************************************
//  Module:         The info field area
// ****************************************************************************

#include <QtGui>

#include "common.h"
#include "infofield.h"

class t_InfoFieldLocal
{
   public:
      QLabel *pLabelParams;
      QLabel *pLabelValues;
};

t_InfoField::t_InfoField ()
{
   CHK_EXIT (ERROR_INFOFIELD_CONSTRUCTOR_NOT_SUPPORTED)
} //lint !e1401 not initialised

t_InfoField::t_InfoField (QWidget *pParent)
   :QFrame (pParent)
{
   CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_INFOFIELD_CONSTRUCTOR_NOT_SUPPORTED))

   setFrameStyle ((int)QFrame::Panel | (int)QFrame::Sunken);
   pOwn = new t_InfoFieldLocal;

   QHBoxLayout *pLayout = new QHBoxLayout (this);
   pOwn->pLabelParams = new QLabel (this);
   pOwn->pLabelValues = new QLabel (this);
   pLayout->addWidget (pOwn->pLabelParams);
   pLayout->addWidget (pOwn->pLabelValues);
   pLayout->addStretch();

   pOwn->pLabelParams->setText (tr("Size")                 + "\n" +
                                tr("Sector size")          + "\n" +
                                tr("Sector size physical") + "\n" +
                                tr("Image file")           + "\n" +
                                tr("Info file")            + "\n" +
                                tr("Current speed"));
}

t_InfoField::~t_InfoField ()
{
   delete pOwn->pLabelParams;
   delete pOwn->pLabelValues;
   delete pOwn;
}

void t_InfoField::SlotShowInfo (t_pDevice pDevice)
{
   QString StrValue, StrSize, StrSpeed, Format;
   quint64 Size;
   QLocale Locale;

   if (pDevice)
   {
      Size = t_Device::GetSize (pDevice).toULongLong();
      StrSize = Locale.toString(Size) + " " + tr("bytes");
      StrSize += " (" + t_Device::GetSizeHuman (pDevice).toString() + ")";

      StrValue = StrSize;
      StrValue += "\n" + t_Device::GetSectorSize    (pDevice).toString();
      StrValue += "\n" + t_Device::GetSectorSizePhys(pDevice).toString();

      if (pDevice->Acquisition.Format == t_File::NotSet)
      {
         StrValue += "\n";
         StrValue += "\n";
      }
      else
      {
         CHK_EXIT (t_File::GetFormatExtension   (pDevice->Acquisition.Format, NULL, &Format))
         StrValue += "\n" + pDevice->Acquisition.Path + pDevice->Acquisition.ImageFilename + QSTR_TO_PSZ(Format);
         StrValue += "\n" + pDevice->Acquisition.Path + pDevice->Acquisition.InfoFilename  + t_File::pExtensionInfo;
      }
      StrSpeed = t_Device::GetCurrentSpeed  (pDevice).toString();
      if (!StrSpeed.isEmpty())
         StrSpeed += " MB/s";
      StrValue += "\n" + StrSpeed;
   }
   pOwn->pLabelValues->setText (StrValue);
}

