// ****************************************************************************
//  Project:        GUYMAGER
// ****************************************************************************
//  Programmer:     Guy Voncken
//                  Police Grand-Ducale
//                  Service de Police Judiciaire
//                  Section Nouvelles Technologies
// ****************************************************************************
//  Module:         Thread for calculating MD5 sum
// ****************************************************************************

#include <openssl/md5.h>

#include <QtCore>

#include "common.h"
#include "device.h"
#include "threadmd5.h"
#include "threadwrite.h"

#if (LIBEWF_VERSION < 20071111)
   #include "libewf.h"
#endif

class t_ThreadMD5Local
{
   public:
      t_pDevice pDevice;
};

t_ThreadMD5::t_ThreadMD5(void)
{
   CHK_EXIT (ERROR_THREADMD5_CONSTRUCTOR_NOT_SUPPORTED)
} //lint !e1401 not initialised


t_ThreadMD5::t_ThreadMD5 (t_pDevice pDevice)
{
   static bool Initialised = false;

   if (!Initialised)
   {
      CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_THREADMD5_CONSTRUCTOR_NOT_SUPPORTED))
      CHK_EXIT (TOOL_ERROR_REGISTER_CODE (ERROR_THREADMD5_LIBEWF_FAILED))
      Initialised = true;
   }

   pOwn = new t_ThreadMD5Local;
   pOwn->pDevice = pDevice;

   CHK_QT_EXIT (connect (this, SIGNAL(finished()), this, SLOT(SlotFinished())))
}

t_ThreadMD5::~t_ThreadMD5 (void)
{
   delete pOwn;
}


void t_ThreadMD5::run (void)
{
   t_pDevice    pDevice;
   t_pFifoBlock pFifoBlock;
   MD5_CTX       MD5Context;
   bool          Finished = false;
   quint64       Blocks   = 0;
   #if (LIBEWF_VERSION < 20071111)
      LIBEWF_HANDLE *pEwfHandle= NULL;
      int             rc;
   #endif

   LOG_INFO ("Acquisition of %s: MD5 thread started", QSTR_TO_PSZ (pOwn->pDevice->LinuxDevice))

   pDevice = pOwn->pDevice;
   (void) MD5_Init (&MD5Context);    // strange, man page says that MD5_Init returns void, but header file says it's int

   #if (LIBEWF_VERSION < 20071111)
      if (pDevice->HasCompressionThreads())
         CHK_EXIT (pDevice->pThreadWrite->GetpFileHandle ((void **)&pEwfHandle))
   #endif

   do
   {
      CHK_EXIT (pDevice->pFifoMD5In->Get (pFifoBlock))
      if (pFifoBlock)
      {
         Blocks++;
         (void) MD5_Update (&MD5Context, pFifoBlock->Buffer, (unsigned long) pFifoBlock->DataSize); // Same remark as for MD5_Init
         #if (LIBEWF_VERSION < 20071111)
            if (pDevice->HasCompressionThreads())
            {
               rc = libewf_raw_update_md5 (pEwfHandle, pFifoBlock->Buffer, (unsigned long) pFifoBlock->DataSize);
               if (rc != 1)
                  CHK_EXIT (ERROR_THREADMD5_LIBEWF_FAILED)
            }
         #endif
         CHK_EXIT (pDevice->pFifoMD5Out->Insert (pFifoBlock))
      }
      else
      {
         LOG_INFO ("Dummy block")
         Finished = true;
      }
   } while (!Finished && !pDevice->AbortRequest);

   (void) MD5_Final (pDevice->MD5Digest, &MD5Context); // Same remark as for MD5_Init

   LOG_INFO ("MD5 thread exits now (device %s, %Ld blocks processed)", QSTR_TO_PSZ (pOwn->pDevice->LinuxDevice), Blocks)
}


void t_ThreadMD5::SlotFinished (void)
{
   emit SignalEnded (pOwn->pDevice);
}

